==> haskell-tagged-0.8.7-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagged
version:              0.8.7
visibility:           public
id:                   tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf
key:                  tagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf
license:              BSD-3-Clause
copyright:            2009-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/tagged
synopsis:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments

description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments.

category:             Data, Phantom Types
abi:                  7a95ad949f8f0da203c5faba082224c2
exposed:              True
exposed-modules:      Data.Proxy.TH Data.Tagged
import-dirs:          /usr/lib/ghc-9.0.2/site-local/tagged-0.8.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/tagged-0.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagged
hs-libraries:         HStagged-0.8.7-8MQxDldL1qw9fJF5LZxnpf
depends:
    base-4.15.1.0 deepseq-1.4.5.0 template-haskell-2.17.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html:         /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagged-0.8.8-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagged
version:              0.8.8
visibility:           public
id:                   tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
key:                  tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
license:              BSD-3-Clause
copyright:            2009-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/tagged
synopsis:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments

description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments.

category:             Data, Phantom Types
abi:                  521fe3f936870f499d0cbeb5923d87a3
exposed:              True
exposed-modules:      Data.Proxy.TH Data.Tagged
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tagged-0.8.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tagged-0.8.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagged
hs-libraries:         HStagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
depends:
    base-4.16.4.0 deepseq-1.4.6.1 template-haskell-2.18.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html:         /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
